@@ -1,4 +1,4 @@
-# Copyrights 2007-2019 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2007-2021 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -8,7 +8,7 @@
 
 package XML::Compile::SOAP::Server;
 use vars '$VERSION';
-$VERSION = '3.25';
+$VERSION = '3.27';
 
 
 use warnings;
@@ -61,10 +61,10 @@ sub compileHandler(@)
         my $data;
         if($decode)
         {   $data = try { $decode->($xmlin) };
-            if($@)
-            {   $@->wasFatal->throw(reason => 'INFO', is_fatal => 0);
+            if(my $err = $@->wasFatal)
+            {   $err->throw(reason => 'INFO', is_fatal => 0);
                 return ( RC_NOT_ACCEPTABLE, 'input validation failed'
-                   , $self->faultValidationFailed($name, $@->wasFatal))
+                   , $self->faultValidationFailed($name, $err))
             }
         }
         else
@@ -114,21 +114,20 @@ sub compileFilter(@)
         # can only base the selection on the type of the elements.  Therefore,
         # procedure selection is often based on HTTP header (which was created
         # for other purposes.
-		my $first = $args{body}{parts}[0] or panic;
-        $need_node = $first->{element} or panic;
+        my $first = $args{body}{parts}[0];
+        $need_node = $first ? $first->{element} : undef;
     }
 
-    my ($need_ns, $need_local) = $need_node ? unpack_type($need_node) : ();
+    $need_node
+        or return sub { !defined $_[1]->{body}[0] };  # empty body
+
+    my ($need_ns, $need_local) = unpack_type($need_node);
 
     # The returned code-ref is called with (XML, INFO)
     sub {
         my ($xml, $info) = @_;
-#use Data::Dumper;
-#warn Dumper \@_;
-#warn $_[0]->toString;
         (my $body) = $xml->getChildrenByLocalName('Body');
         (my $has)  = $body->getElementsByTagNameNS($need_ns, $need_local);
-#warn $has->toString;
         defined $has;
     };
 }
