@@ -1,4 +1,4 @@
-# Copyrights 2007-2019 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2007-2021 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -8,7 +8,7 @@
 
 package XML::Compile::SOAP11::Operation;
 use vars '$VERSION';
-$VERSION = '3.25';
+$VERSION = '3.27';
 
 use base 'XML::Compile::SOAP::Operation';
 
@@ -97,8 +97,8 @@ sub _msg_parts($$$$$)
            : @parts==1 && $parts[0]{type} ? $msgname
            : $local; 
 
-        $parts{body}  = {procedure => $procedure, %$port_op, use => 'literal'
-           , %$body, parts => \@parts};
+        $parts{body}  = { procedure => $procedure, %$port_op, use => 'literal'
+           , %$body, parts => \@parts };
     }
     elsif($port_op->{message})
     {   # missing <soap:body use="literal"> in <wsdl:input> or :output
@@ -444,7 +444,7 @@ sub explain($$$@)
     if(my $how = $def->{body})
     {   my $use  = $how->{use} || 'literal';
         push @header
-          , "# Operation $how->{procedure}"
+          , "# Operation ". ($how->{procedure} || '(unnamed)')
           , "#           $dir, $style $use";
     }
     else
